# WordPress.com End to End Tests

Automated end-to-end acceptance tests for the [wp-calypso](https://github.com/Automattic/wp-calypso) client and WordPress.com in general.

## Table of contents

- [Overview](docs/overview.md)
  - [What is this?](docs/overview.md#what-is-this)
  - [Our Goals](docs/overview.md#our-goals)
  - [Technology](docs/overview.md#technology)
  - [What is tested?](docs/overview.md#what-is-tested)
- [Setup](docs/setup.md)
  - [Software Environment](docs/setup.md#software-environment)
  - [Configuration](docs/setup.md#configuration)
  - [Environment Variables](docs/setup.md#environment-variables)
  - [Naming Branches](docs/setup.md#naming-branches)
- [Running tests](docs/running-tests.md)
  - [Local Against Staging](docs/running-tests.md#local)
    - [Run all tests default](docs/running-tests.md#run-all-tests-default)
    - [Run individual spec](docs/running-tests.md#run-individual-spec)
    - [Run individual case](docs/running-tests.md#run-individual-case)
    - [Modes](docs/running-tests.md#modes)
    - [Headless](docs/running-tests.md#headless)
    - [Other options](docs/running-tests.md#other-options)
  - [Local Development Environment](docs/running-tests.md#local-development-environment)
  - [CircleCI](docs/running-tests.md#circleci)
    - [Canary](docs/running-tests.md#circleci#canary)
    - [Full suite](docs/running-tests.md#circleci#full-suite)
  - [Sauce Labs](docs/running-tests.md#sauce-labs)
- [Debugging](docs/debugging.md#debugging)
  - [Table of contents](docs/debugging.md#table-of-contents)
  - [Visual Studio Code](docs/debugging.md#visual-studio-code)
  - [Enable Mocha Debug Output](docs/debugging.#enable-mocha-debug-output)
- [Writing tests](docs/writing_tests.md)
  - [Selector](docs/writing_tests.md#selector)
    - [How](docs/writing_tests.md#how)
  - [Component](docs/writing_tests.md#component)
  - [Page Object Model](docs/writing_tests.md#page-object-model)
    - [Structure](docs/writing_tests.md#structure)
    - [Guidelines](docs/writing_tests.md#guidelines)
  - [Flow](docs/writing_tests.md#flow)
    - [Structure](docs/writing_tests.md#structure)
    - [Guidelines](docs/writing_tests.md#guidelines)
- [Style Guide](docs/style-guide.md)
  - [Async / Await](docs/style-guide.md#async--await)
  - [Tags](docs/style-guide.md#tags)
  - [Page Objects](docs/style-guide.md#page-objects)
  - [Use of this, const and lets](docs/style-guide.md#use-of-this-const-and-lets)
  - [Arrow functions](docs/style-guide.md#arrow-functions)
  - [Default values using destructuring](docs/style-guide.md#default-values-using-destructuring)
  - [Nesting step blocks](docs/style-guide.md#nesting-step-blocks)
  - [Catching errors in a step block](docs/style-guide.md#catching-errors-in-a-step-block)
  - [Waiting for elements](docs/style-guide.md#waiting-for-elements)
- [Troubleshooting & Debugging](docs/troubleshooting.md)
  - [git pre-commit hook/husky](docs/troubleshooting.md#git-pre-commit-hookhusky)
